@@ -474,13 +474,16 @@ class StateDB:
             index = 'state_updated'
             expr = expr & Key(index).begins_with(state)
 
-        keys = ['collections_workflow', 'itemids']
+        exclusive_start_key_filters = ["collections_workflow", "itemids"]
 
         if index:
             kwargs['IndexName'] = index
+            exclusive_start_key_filters = ["collections_workflow", "itemids"]
 
-        if 'ExclusiveStartKey' in kwargs:
-            kwargs['ExclusiveStartKey'] = {k: kwargs['ExclusiveStartKey'][k] for k in keys}
+        if "ExclusiveStartKey" in kwargs:
+            kwargs["ExclusiveStartKey"] = {
+                k: kwargs["ExclusiveStartKey"][k] for k in exclusive_start_key_filters
+            }
 
         kwargs.update({
             'KeyConditionExpression': expr,
@@ -491,7 +494,7 @@ class StateDB:
         if self.limit and (not 'Limit' in kwargs or self.limit < kwargs['Limit']):
             kwargs['Limit'] = self.limit
 
-        print(kwargs)
+        logger.debug(kwargs)
         resp = self.table.query(**kwargs)
 
         return resp
